"""
novyx-core is DEPRECATED. Use 'novyx' instead.

    pip install novyx

See https://pypi.org/project/novyx/ for the official SDK.
"""

import warnings

warnings.warn(
    "novyx-core is deprecated. Install 'novyx' instead: pip install novyx. "
    "See https://pypi.org/project/novyx/",
    DeprecationWarning,
    stacklevel=2,
)

# Re-export from the real package so existing code doesn't break immediately
try:
    from novyx import Novyx, __version__
except ImportError:
    pass
